<?php

class SGP_Theme_Module extends SGP_Module {

	const moduleName = 'Theme';

	protected static $instance;
	protected static $_vars = NULL;
	protected static $_params = array();
	protected static $_fields = array();
	protected static $_description = NULL;

	private function __construct()
	{
		self::$_fields = array(
			'main_color' => array(
				'name' => __('Theme Skin', SG_TDN),
				'type' => 'select',
				'options' => array(
					'light' => __('Light', SG_TDN),
					'dark' => __('Dark', SG_TDN),
				),
				'default' => 'light',
				'help' => __('Choose light or dark style of the theme', SG_TDN),
			),
			'first_color' => array(
				'name' => __('Primary Color', SG_TDN),
				'type' => 'color',
				'default' => '#ff4747',
				'help' => __('Main theme color', SG_TDN),
			),
			'second_color' => array(
				'name' => __('Secondary Color', SG_TDN),
				'type' => 'color',
				'default' => '#404040',
				'help' => __('Color of Headings and some other elements', SG_TDN),
			),
			'body_color' => array(
				'name' => __('Body color', SG_TDN),
				'type' => 'color',
				'default' => '#f5f5f5',
				'help' => __('Background color of the page', SG_TDN),
			),
			'font_type' => array(
				'name' => __('Font Type', SG_TDN),
				'type' => 'checkbox',
				'options' => array(
					'latin' => __('Latin', SG_TDN),
					'latin-ext' => __('Latin Ext', SG_TDN),
					'cyrillic' => __('Cyrillic', SG_TDN),
					'cyrillic-ext' => __('Cyrillic Ext', SG_TDN),
					'greek' => __('Greek', SG_TDN),
					'greek-ext' => __('Greek Ext', SG_TDN),
					'vietnamese' => __('Vietnamese', SG_TDN),
				),
				'default' => 'latin',
				'help' => __('Select language support to exclude unnecessary fonts from the selection
				list', SG_TDN),
			),
			'hfont' => array(
				'name' => __('Heading Font', SG_TDN),
				'type' => 'select',
				'options' => array(
					'Open+Sans+Condensed' => 'Open Sans Condensed',
					'Podkova' => 'Podkova',
					'Signika' => 'Signika',
					'PT+Sans+Narrow' => 'PT Sans Narrow',
					'Economica' => 'Economica',
					'Oswald' => 'Oswald',
					'Yanone+Kaffeesatz' => 'Yanone Kaffeesatz',
					'Merriweather' => 'Merriweather',
					'Cuprum' => 'Cuprum',
					'Advent+Pro' => 'Advent Pro',
					'Ubuntu+Condensed' => 'Ubuntu Condensed',
					'Helvetica' => 'Helvetica',
					'Arial' => 'Arial',
				),
				'default' => 'Open+Sans+Condensed',
				'help' => __('Heading Font', SG_TDN),
			),
			'cfont' => array(
				'name' => __('Content Font', SG_TDN),
				'type' => 'select',
				'options' => array(
					'Open+Sans' => 'Open Sans',
					'Ubuntu' => 'Ubuntu',
					'Helvetica' => 'Helvetica',
					'Merriweather' => 'Merriweather',
					'PT+Sans' => 'PT Sans',
					'Istok+Web' => 'Istok Web',
					'Arial' => 'Arial',
					'Georgia' => 'Georgia',
				),
				'default' => 'Open+Sans',
				'help' => __('Content Font', SG_TDN),
			),
		);
	}

	private function __clone() {}

	public static function getInstance()
	{
		if (is_null(self::$instance)) {
			self::$instance = new SGP_Theme_Module;
		}
		return self::$instance;
	}

	public function inited()
	{
		return !is_null(self::$_vars);
	}

	public function initVars($params, $defaults)
	{
		self::$_vars = self::_initVars(self::moduleName, self::$_params, self::$_fields, $params, $defaults);
		return TRUE;
	}

	public function setVars($post_data)
	{
		return self::_setVars(self::moduleName, self::$_fields, $post_data);
	}

	public function resetVars()
	{
		return self::_resetVars(self::moduleName);
	}

	protected function _getColorField($uid, $params, $value, $default, $ug)
	{
		$c = SG_Form::input($uid, $value, array('id' => 'link-color-' . $uid));
		$c .= '<a href="#" class="sg-pickcolor hide-if-no-js" id="link-color-example-' . $uid . '"></a>';
		$c .= '<div id="colorPickerDiv-' . $uid . '" class="sg-colorPickerDiv"></div>';

		$c .= '<script type="text/javascript">';
		$c .= '
//<![CDATA[
jQuery(document).ready(function($){
	var farbtastic_' . $uid . ';
	(function($){
		var pickColor_' . $uid . ' = function(a) {
			farbtastic_' . $uid . '.setColor(a);
			$("#link-color-' . $uid . '").val(a.toUpperCase());
			$("#link-color-example-' . $uid . '").css("background-color", a);
			' . ($uid == 'sgp_Theme_body_color' ? 'sg_sgp_bg_color = a;' : '') .
				($uid == 'sgp_Theme_body_color' ? '$(".sg-slide-img-p").css("background-color", a);' : '') .
		'};

		$(document).ready( function() {
			if ($("#colorPickerDiv-' . $uid . '").size() > 0) {
				farbtastic_' . $uid . ' = $.farbtastic("#colorPickerDiv-' . $uid . '", pickColor_' . $uid . ');
				pickColor_' . $uid . '( $("#link-color-' . $uid . '").val() );

				$("#link-color-example-' . $uid . '").click( function(e) {
					$("#colorPickerDiv-' . $uid . '").show();
					e.preventDefault();
				});

				$("#link-color-' . $uid . '").keyup( function() {
					var a = $("#link-color-' . $uid . '").val(),
						b = a;
					a = a.replace(/[^a-fA-F0-9]/, "");
					if ( "#" + a !== b )
						$("#link-color-' . $uid . '").val(a);
					if ( a.length === 3 || a.length === 6 )
						pickColor_' . $uid . '( "#" + a );
				});

				$(document).mousedown( function() {
					$(".sg-colorPickerDiv").hide();
				});
			}
		});
	})(jQuery);
});
//]]>
			';
		$c .= '</script>';

		return $c;
	}

	public function getAdminContent($params, $defaults)
	{
		$c = self::_getAdminContent(self::moduleName, self::$_params, self::$_fields, self::$_description, $params, $defaults);

		$c .= '<script type="text/javascript">';
		$c .= '
//<![CDATA[
jQuery(document).ready(function($){
	function sgp_set_fonts_type(){
		var cft = [];

		$("input[name=\'sgp_Theme_font_type[]\']:checked").each(function(){
			cft.push($(this).val());
		});

		var ft = {
			"Signika" : ["latin","latin-ext"],
			"Economica" : ["latin","latin-ext"],
			"Oswald" : ["latin","latin-ext"],
			"Yanone+Kaffeesatz" : ["latin"],
			"Podkova" : ["latin"],
			"Merriweather" : ["latin"],
			"PT+Sans+Narrow" : ["latin","cyrillic","latin-ext"],
			"Cuprum" : ["latin","cyrillic"],
			"Advent+Pro" : ["latin","greek","latin-ext"],
			"Ubuntu+Condensed" : ["latin","cyrillic-ext","greek-ext","greek","latin-ext","cyrillic"],
			"Open+Sans+Condensed" : ["latin","cyrillic-ext","greek-ext","greek","latin-ext","vietnamese","cyrillic"],
			"Open+Sans" : ["latin","cyrillic-ext","greek-ext","greek","latin-ext","vietnamese","cyrillic"],
			"PT+Sans" : ["latin","latin-ext","cyrillic","cyrillic-ext"],
			"Istok+Web" : ["latin","latin-ext","cyrillic","cyrillic-ext"],
			"Ubuntu" : ["latin","cyrillic-ext","greek-ext","greek","latin-ext","cyrillic"],
			"Georgia" : ["latin","cyrillic-ext","greek-ext","greek","latin-ext","vietnamese","cyrillic"],
			"Helvetica" : ["latin","cyrillic-ext","greek-ext","greek","latin-ext","vietnamese","cyrillic"],
			"Arial" : ["latin","cyrillic-ext","greek-ext","greek","latin-ext","vietnamese","cyrillic"]
		};

		$("select[name=sgp_Theme_hfont] option").each(function(){
			var found = false;
			$(this).attr("disabled", false);
			for (key1 in cft) {
				found = false;
				for (key2 in ft[$(this).val()]) {
					if (cft[key1] == ft[$(this).val()][key2]) {
						found = true;
						break;
					}
				}
				if (!found) {
					$(this).attr("disabled", true);
					break;
				}
			}
		});

		$("select[name=sgp_Theme_cfont] option").each(function(){
			var found = false;
			$(this).attr("disabled", false);
			for (key1 in cft) {
				found = false;
				for (key2 in ft[$(this).val()]) {
					if (cft[key1] == ft[$(this).val()][key2]) {
						found = true;
						break;
					}
				}
				if (!found) {
					$(this).attr("disabled", true);
					break;
				}
			}
		});

		$("select[name=sgp_Theme_dfont] option").each(function(){
			var found = false;
			$(this).attr("disabled", false);
			for (key1 in cft) {
				found = false;
				for (key2 in ft[$(this).val()]) {
					if (cft[key1] == ft[$(this).val()][key2]) {
						found = true;
						break;
					}
				}
				if (!found) {
					$(this).attr("disabled", true);
					break;
				}
			}
		});
	}

	function sgp_set_fonts_type_c(){
		sgp_set_fonts_type();
		$("select[name=sgp_Theme_hfont] option:enabled:first").attr("selected", true);
		$("select[name=sgp_Theme_cfont] option:enabled:first").attr("selected", true);
		$("select[name=sgp_Theme_dfont] option:enabled:first").attr("selected", true);
	}

	$("input[name=\'sgp_Theme_font_type[]\']:first").attr("checked", "checked").attr("disabled", "true");
	sgp_set_fonts_type(true);

	$("input[name=\'sgp_Theme_font_type[]\']").click(sgp_set_fonts_type_c);
});
//]]>
			';
		$c .= '</script>';

		return $c;
	}

	public function getMainClass()
	{
		return (self::$_vars['main_color'] == 'dark' ? ' ef-dark-theme' : '');
	}

	public function eCSS()
	{
		if (!_sg('Modules')->enabled('Theme'))	return;

		$acolor = self::$_vars['first_color'];
		$scolor = self::$_vars['second_color'];
		$bcolor = self::$_vars['body_color'];

		$cfont = '"' . str_replace('+', ' ', self::$_vars['cfont']) . '"' . (self::$_vars['cfont'] != 'San-Serif' ? ', "sans-serif"' : '');
		$hfont = '"' . str_replace('+', ' ', self::$_vars['hfont']) . '"' . (self::$_vars['cfont'] != 'San-Serif' ? ', "sans-serif"' : '');

		$fonts = array(
			'Signika' => ':400,300,600,700',
			'PT+Sans+Narrow' => ':400,700',
			'Economica' => ':400,700,400italic,700italic',
			'Oswald' => ':400,300',
			'Yanone+Kaffeesatz' => ':400,300,200',
			'Podkova' => ':400,700',
			'Merriweather' => ':400,700',
			'Cuprum' => '',
			'Advent+Pro' => ':400,100,200,300,500,600,700',
			'Ubuntu+Condensed' => '',
			'Open+Sans+Condensed' => ':700,300,300italic',
			'Open+Sans' => ':400,300,300italic,400italic,600,600italic,700,700italic,800,800italic',
			'PT+Sans' => ':400,700,400italic,700italic',
			'Istok+Web' => ':400,400italic,700,700italic',
			'Ubuntu' => ':400,300,300italic,400italic,500,500italic,700,700italic',
			'Georgia' => 'Georgia',
			'Helvetica' => 'Helvetica',
			'Arial' => 'Arial',
		);

		$fontscex = array(
			'Signika' => '',
			'PT+Sans+Narrow' => '',
			'Economica' => '',
			'Oswald' => '',
			'Yanone+Kaffeesatz' => '',
			'Podkova' => '',
			'Merriweather' => '',
			'Cuprum' => '',
			'Advent+Pro' => '',
			'Ubuntu+Condensed' => '',
			'Open+Sans+Condensed' => '',
			'Open+Sans' => '',
			'PT+Sans' => '',
			'Istok+Web' => '',
			'Ubuntu' => '',
			'Georgia' => '',
			'Helvetica' => '',
			'Arial' => '',
		);

		echo '<style type="text/css">';
			echo '.ef-column {background-color:' . $bcolor . ';}' . "\n";
			echo "\n";
			echo 'h1 a, h2 a, h3 a, h4 a, h5 a, h6 a, .ef-post-details div a:hover, .ef-form div label span, .ef-form div.send-wrap span span, #ef-office-1:hover, #ef-office-2:hover, .tabs-nav .ui-tabs-selected a, .ef-accordion .ui-accordion-header.ui-state-active a, .ef-toggle-box li.open a, a.ef-button:hover, #wp-calendar a, .tagcloud a:hover, #ef-topbar #wp-calendar a:hover, .comment-reply-link:hover, .ef-pagination-comments a, .ef-sidebar-wrapper .ef-post-details a:hover, ul li a:hover, ol li a:hover, p a:hover, .ef-toggle-box.toggle-icn li.open .toggle-head, .ef-tabs ul.tabs-nav li.ui-tabs-active a, .gallery-item:hover .gallery-caption, .ef-sc-button:hover {color:' . $acolor . ';}' . "\n";
			echo '.ef-tooltip:before, #ef-topbar-button .ef-tooltip:before, #tray-button div .ef-tooltip:before, .ef-sc-button.ef-theme {border-color:' . $acolor . ';}' . "\n";
			echo '.ef-navmenu li.backLava, #progress-bar, #prevslide:hover, #nextslide:hover, #thumb-back:hover, #thumb-forward:hover, span.ef-highlight.hl-theme, a span.ef-highlight.hl-dark, .flex-direction-nav li a:hover, .ef-menu-tab, .ef-select-menu, .ef-ie .ef-select-menu option, .ef-form div.send-wrap div input:hover, .ef-big-btn.ef-theme-btn, .ef-big-btn.ef-theme-btn.ef-reversed:hover, #ef-topbar-button.ef-close, #tray-button.ef-close-add div, #ef-topbar-button:hover, #tray-button div:hover, .ef-tooltip, .ef-pagination a.page-active, .recomended .price-title, .ef-slide-link, .ef-sc-button.ef-theme, .ef-first.ef-first-col {background-color:' . $acolor . ';}' . "\n";
			echo '::selection {background-color:' . $acolor . ';}' . "\n";
			echo '::-moz-selection {background-color:' . $acolor . ';}' . "\n";
			echo "\n";
			echo 'h1, h2, h3, h4, h5, h6, div.ef-description p span, strong, #slidecounter, .ef-post-details a, .ef-post-details span, #ui-lightbox-title-wrapper, .ef-filter li a, .ef-filter li.current-cat a span, .ef-form div.send-wrap div input, .ef-button, .widget_portfolio_categories ul li a:hover span, .widget_portfolio_categories ul li a, .widget_portfolio_categories ul li.current-cat a span, .ef-archive, #ef-topbar .widget_portfolio_categories li a:hover, .ef-form .not-valid, .ef-form .not-valid input, .ef-form .ef-textarea .not-valid textarea, .tagcloud a, .ef-pagination a, .comment-reply-link, span.ef-first.ef-no-bg, ul li a, ol li a, p a, table th, .price-item.recomended, .ef-filter li a:hover, .gallery-caption, .ef-accordion .ui-accordion-header a {color:' . $scolor . ';}' . "\n";
			echo '.ef-sc-button.ef-theme:hover {border-color:' . $scolor . ';}' . "\n";
			echo 'span.ef-highlight.hl-dark, a span.ef-highlight.hl-theme, .ef-filter li.current-cat a, .ef-big-btn.ef-theme-btn:hover, .ef-big-btn.ef-theme-btn.ef-reversed, ul.slides .proj-img, .widget_portfolio_categories ul li a:hover, .widget_portfolio_categories ul li.current-cat a, span.ef-first, .ef-slide-link:hover, .ef-sc-button.ef-theme:hover {background-color:' . $scolor . ';}' . "\n";
			echo "\n";
			echo "\n";
			echo 'body, input, textarea, .ef-slide-link {font-family:' . $cfont . ';}' . "\n";
			echo 'h1, h2, h3, h4, h5, .ef-navmenu li a, #slidecaption, .testimonials .ef-author, #ui-lightbox-title, .ef-tabs ul.tabs-nav li a, table th, .price-tag, .price-title, .gallery-caption {font-family:' . $hfont . ' !important;}' . "\n";
			echo "\n";
			if ($fontscex[self::$_vars['cfont']] != '') echo $fontscex[self::$_vars['cfont']];
		echo '</style>';

		echo '<script type="text/javascript">sg_template_color = "' . $acolor . '";</script>';

		if ($fonts[self::$_vars['cfont']] != self::$_vars['cfont']) {
			$subset = is_array(self::$_vars['font_type']) ? self::$_vars['font_type'] : array(self::$_vars['font_type']);
			$subset = implode(',', $subset);
			$subset = ($subset != 'latin') ? '&amp;subset=' . $subset : '';
			echo '<link href="http://fonts.googleapis.com/css?family=' . self::$_vars['cfont'] . $fonts[self::$_vars['cfont']] . $subset . '" rel="stylesheet" type="text/css" />';
		}

		if ($fonts[self::$_vars['hfont']] != self::$_vars['hfont']) {
			$subset = is_array(self::$_vars['font_type']) ? self::$_vars['font_type'] : array(self::$_vars['font_type']);
			$subset = implode(',', $subset);
			$subset = ($subset != 'latin') ? '&amp;subset=' . $subset : '';
			echo '<link href="http://fonts.googleapis.com/css?family=' . self::$_vars['hfont'] . $fonts[self::$_vars['hfont']] . $subset . '" rel="stylesheet" type="text/css" />';
		}
	}

}