<?php

class SG_Blog_Module extends SG_Module {

	const moduleName = 'Blog';

	protected static $instance;
	protected static $_vars = NULL;
	protected static $_params = array();
	protected static $_fields = array();
	protected static $_description = NULL;

	private function __construct()
	{
		self::$_fields = array(
			'featured' => array(
				'name' => __('Featured Post', SG_TDN),
				'type' => 'select',
				'options' => array(
					'no' => 'Default size',
					'size' => 'Double Size',
				),
				'default' => 'size',
				'help' => __('Select "Double Size" if you want to highlight this post among the other or use "Default Size" for general view', SG_TDN),
			),
			'no_imgs' => array(
				'name' => __('Post without a thumbnail', SG_TDN),
				'type' => 'select',
				'options' => array(
					'show' => 'Show Post Icon',
					'hide' => 'Hide Post Icon',
				),
				'default' => 'hide',
				'help' => __('Blog icon will be displayed as a gag in the post without thumbnail image if you select "Show Post Icon" (for the Blog Feed)', SG_TDN),
			),
			'slider_thumbnails' => array(
				'name' => __('Post Slider', SG_TDN),
				'type' => 'select',
				'options' => array(
					'image' => 'Disable',
					'slider' => 'Enable',
				),
				'default' => 'slider',
				'help' => __('Select "Enable" in order to use Slider instead of a thumbnail image in the blog post (for the Blog Feed) or "Disable" to use simple image', SG_TDN),
			),
			'video_thumbnails' => array(
				'name' => __('Video Thumbnail', SG_TDN),
				'type' => 'select',
				'options' => array(
					'image' => 'Disable',
					'video' => 'Enable',
				),
				'default' => 'video',
				'help' => __('Select "Enable" in order to use Video instead of a thumbnail image in the blog post (for the Blog Feed) or "Disable" to use simple image', SG_TDN),
			),
			'posts_count' => array(
				'name' => __('Post Count', SG_TDN),
				'type' => 'select',
				'options' => array(
					'10' => '10',
					'15' => '15',
					'20' => '20',
					'25' => '25',
					'30' => '30',
				),
				'default' => '15',
				'help' => __('Number of posts per page in the Blog Feed', SG_TDN),
			),
			'required_categories' => array(
				'name' => __('Select Required Categories', SG_TDN),
				'type' => 'select2',
				'options' => array(),
				'default' => array(
					'value' => self::USE_ALL,
					'custom' => NULL,
				),
				'show_none' => FALSE,
				'help' => __('Posts from the selected categories will be displayed in the Blog Feed. Choose "Select" then highlight required categories. All posts will be shown if you choose "Use All"', SG_TDN),
			),
		);
	}

	private function __clone() {}

	public static function getInstance()
	{
		if (is_null(self::$instance)) {
			self::$instance = new SG_Blog_Module;
		}
		return self::$instance;
	}

	public function inited()
	{
		return !is_null(self::$_vars);
	}

	public function initVars($uniq, $params, $defaults, $global, $post_id)
	{
		self::$_vars = self::_initVars(self::moduleName, $uniq, self::$_params, self::$_fields, $params, $defaults, $global, $post_id);
		return TRUE;
	}

	public function setVars($uniq, $post_data, $post_id = NULL)
	{
		return self::_setVars(self::moduleName, $uniq, self::$_fields, $post_data, $post_id);
	}

	public function resetVars($uniq, $post_id = NULL)
	{
		return self::_resetVars(self::moduleName, $uniq, $post_id);
	}

	public function getMenuItem()
	{
		return __('Theme', SG_TDN);
	}

	public function getAdminContent($uniq, $params, $defaults, $global = NULL, $post_id = NULL)
	{
		$fields = self::$_fields;

		$cats = get_terms('category', array('hide_empty' => FALSE));
		$topc = array();

		foreach ($cats as $cat) {
			$topc[$cat->term_id] = $cat->name;
		}

		$fields['required_categories']['options'] = $topc;

		return self::_getAdminContent(self::moduleName, $uniq, self::$_params, $fields, self::$_description, $params, $defaults, $global, $post_id);;
	}

	public function getVT()
	{
		return self::$_vars['video_thumbnails'];
	}

	public function getST()
	{
		return self::$_vars['slider_thumbnails'];
	}

	public function getPostsCount()
	{
		return self::$_vars['posts_count'];
	}

	public function getRequiredCategories()
	{
		if (self::$_vars['required_categories']['value'] == self::USE_ALL) return '';
		return self::$_vars['required_categories']['custom'];
	}

	function getFeaturedType()
	{
		return self::$_vars['featured'];
	}

	function isVideoAutoplay()
	{
		return (self::$_vars['video_autoplay'] == 'yes');
	}

	function isNoImg()
	{
		return (self::$_vars['no_imgs'] == 'show');
	}

}