<?php

class SG_Portfolio_Module extends SG_Module {

	const moduleName = 'Portfolio';

	protected static $instance;
	protected static $_vars = NULL;
	protected static $_params = array();
	protected static $_fields = array();
	protected static $_description = NULL;

	private function __construct()
	{
		self::$_fields = array(
			'filter' => array(
				'name' => __('Projects Filter', SG_TDN),
				'type' => 'select',
				'options' => array(
					'filter' => __('Chess Filter', SG_TDN),
					'isotope' => __('Isotope Filter', SG_TDN),
				),
				'default' => 'isotope',
				'show' => self::SHOW_NONE,
				'help' => __('Select filter type for the Portfolio', SG_TDN),
			),
			'filter_count' => array(
				'name' => __('Projects Count', SG_TDN),
				'type' => 'select',
				'options' => array(
					'all' => __('All projects', SG_TDN),
					'now' => __('Displayed projects', SG_TDN),
				),
				'default' => 'now',
				'help' => __('Select projects count for the Portfolio Categories', SG_TDN),
			),
			'featured' => array(
				'name' => __('Featured Project', SG_TDN),
				'type' => 'select',
				'options' => array(
					'no' => 'Default size',
					'badge' => 'Show Badge',
					'size' => 'Double Size',
					'yes' => 'Double Size + Badge',
				),
				'default' => 'size',
				'help' => __('Select "Double Size" if you want to highlight this post among the other or use "Default Size" for general view. Also you are able to choose "Show Badge" which will be displayed in the thumbnail (in the Portfolio Feed) or choose "Double Size + Badge" to apply these two properties', SG_TDN),
			),
			'hover' => array(
				'name' => __('Hover State', SG_TDN),
				'type' => 'select',
				'options' => array(
					'all' => __('Link + Lightbox', SG_TDN),
					'link' => __('Link', SG_TDN),
					'lightbox' => __('Lightbox', SG_TDN),
				),
				'default' => 'all',
				'change' => array(
					'hover' => '["all","lightbox"]',
				),
				'help' => __('Choose link type in thumbnail', SG_TDN),
			),
			'video_thumbnails' => array(
				'name' => __('Video/image in the Lightbox', SG_TDN),
				'type' => 'select',
				'options' => array(
					'image' => __('Image', SG_TDN),
					'video' => __('Video', SG_TDN),
				),
				'default' => 'image',
				'group' => 'hover',
				'help' => __('Choose lightbox type', SG_TDN),
			),
			'posts_count' => array(
				'name' => __('Project Count', SG_TDN),
				'type' => 'select',
				'options' => array(
					'10' => '10',
					'15' => '15',
					'20' => '20',
					'25' => '25',
					'30' => '30',
					'30' => '35',
					'30' => '40',
					'30' => '45',
					'30' => '50',
				),
				'default' => '20',
				'help' => __('Number of projects per page in the Portfolio Feed', SG_TDN),
			),
			'required_categories' => array(
				'name' => __('Select Required categories', SG_TDN),
				'type' => 'select2',
				'options' => array(),
				'default' => array(
					'value' => self::USE_ALL,
					'custom' => NULL,
				),
				'show_none' => FALSE,
				'help' => __('Projects from the selected categories will be displayed in the Blog Feed. Choose "Select" then highlight required categories. All posts will be shown if you choose "Use All"', SG_TDN),
			),
		);
	}

	private function __clone() {}

	public static function getInstance()
	{
		if (is_null(self::$instance)) {
			self::$instance = new SG_Portfolio_Module;
		}
		return self::$instance;
	}

	public function inited()
	{
		return !is_null(self::$_vars);
	}

	public function initVars($uniq, $params, $defaults, $global, $post_id)
	{
		self::$_vars = self::_initVars(self::moduleName, $uniq, self::$_params, self::$_fields, $params, $defaults, $global, $post_id);
		return TRUE;
	}

	public function setVars($uniq, $post_data, $post_id = NULL)
	{
		return self::_setVars(self::moduleName, $uniq, self::$_fields, $post_data, $post_id);
	}

	public function resetVars($uniq, $post_id = NULL)
	{
		return self::_resetVars(self::moduleName, $uniq, $post_id);
	}

	public function getMenuItem()
	{
		return __('Content', SG_TDN);
	}

	public function getAdminContent($uniq, $params, $defaults, $global = NULL, $post_id = NULL)
	{
		$fields = self::$_fields;

		$tags = get_terms('portfolio_category', array('hide_empty' => FALSE));
		$topt = array();

		foreach ($tags as $tag) {
			$topt[$tag->term_id] = $tag->name;
		}

		$fields['required_categories']['options'] = $topt;

		return self::_getAdminContent(self::moduleName, $uniq, self::$_params, $fields, self::$_description, $params, $defaults, $global, $post_id);;
	}

	public function getVT()
	{
		return self::$_vars['video_thumbnails'];
	}

	public function getFilter()
	{
		return self::$_vars['filter'];
	}

	public function getPostsCount()
	{
		return self::$_vars['posts_count'];
	}

	public function getRequiredCategories()
	{
		if (self::$_vars['required_categories']['value'] == self::USE_ALL) return '';
		return self::$_vars['required_categories']['custom'];
	}

	function getFeaturedType()
	{
		return self::$_vars['featured'];
	}

	function getHoverType()
	{
		return self::$_vars['hover'];
	}

	function isVideoAutoplay()
	{
		return (self::$_vars['video_autoplay'] == 'yes');
	}

	function eFilterCount()
	{
		echo 'ef-sg-' . self::$_vars['filter_count'];
	}

}