<?php

class SG_PortfolioPost_Module extends SG_Module {

	const moduleName = 'PortfolioPost';

	protected static $instance;
	protected static $_vars = NULL;
	protected static $_params = array();
	protected static $_fields = array();
	protected static $_description = NULL;

	private function __construct()
	{
		self::$_fields = array(
			'show_back' => array(
				'name' => __('Back Button', SG_TDN),
				'type' => 'select',
				'options' => array(
					'yes' => __('Show', SG_TDN),
					'left' => __('In the Mainbar', SG_TDN),
					'right' => __('In the Sidebar', SG_TDN),
					'no' => __('Hide', SG_TDN),
				),
				'default' => 'yes',
				'show' => self::SHOW_GLOBAL,
				'help' => __('Show/hide "Back to the Portfolio" button. Also you are able to choose it to be shown only in the Mainbar (on the left of a page) or in the Sidebar of a page', SG_TDN),
			),
			'show_pn' => array(
				'name' => __('Previous and Next Post Buttons', SG_TDN),
				'type' => 'select',
				'options' => array(
					'yes' => __('Show', SG_TDN),
					'left' => __('In the Mainbar', SG_TDN),
					'right' => __('In the Sidebar', SG_TDN),
					'no' => __('Hide', SG_TDN),
				),
				'default' => 'yes',
				'show' => self::SHOW_GLOBAL,
				'help' => __('Show/hide "Previous and Next Post" buttons. Also you are able to choose it to be shown only in the Mainbar (on the left of a page) or in the Sidebar of a page', SG_TDN),
			),
			'featured' => array(
				'name' => __('Featured Post', SG_TDN),
				'type' => 'select',
				'options' => array(
					'simple' => __('Default size', SG_TDN),
					'featured' => __('Double size', SG_TDN),
				),
				'default' => 'simple',
				'help' => __('Select "Double Size" if you want to highlight this post among the other or use "Default Size" for general view', SG_TDN),
			),
			'type' => array(
				'name' => __('Project Type', SG_TDN),
				'type' => 'select',
				'options' => array(
					'img' => __('Image/Slider', SG_TDN),
					'video' => __('Video', SG_TDN),
				),
				'default' => 'img',
				'change' => array(
					'image' => '["img"]',
					'video' => '["video"]',
				),
				'help' => __('Type of a project', SG_TDN),
			),
			'slider' => array(
				'name' => __('Portfolio Post Images', SG_TDN),
				'type' => 'slides',
				'class' => 'sg-metabox-field sg-metabox-slides2',
				'default' => array(
					'value' => self::USE_NONE,
					'slides' => array(),
				),
				'group' => 'image',
				'help' => __('Add a thumbnail image (1172px in width is preferable) for post or some images by pressing "+" to apply Slider', SG_TDN),
			),
			'slider_type' => array(
				'name' => __('Portfolio Slider Type', SG_TDN),
				'type' => 'slides',
				'type' => 'select',
				'options' => array(
					'simple' => __('Simple Slider', SG_TDN),
					'thumbnail' => __('Slider With Thumbnail Navigation', SG_TDN),
				),
				'default' => 'thumbnail',
				'group' => 'image',
				'help' => __('Portfolio Slider Type', SG_TDN),
			),
			'img' => array(
				'name' => __('Get video thumbnail', SG_TDN),
				'type' => 'thumbnail',
				'default' => '',
				'group' => 'video',
				'help' => __('Get video thumbnail for the project', SG_TDN),
			),
			'video' => array(
				'name' => __('Video Link', SG_TDN),
				'type' => 'input',
				'class' => 'sg-metabox-field sg-metabox-long',
				'default' => '',
				'group' => 'video',
				'help' => __('Enter a link to Vimeo or YouTube video page', SG_TDN),
			),
			'parent' => array(
				'name' => __('Parent', SG_TDN),
				'type' => 'select',
				'options' => array(),
				'default' => '#',
				'show' => self::SHOW_ALL,
				'help' => __('Select parent portfolio page to be displayed in the breadcrumbs', SG_TDN),
			),
		);
	}

	private function __clone() {}

	public static function getInstance()
	{
		if (is_null(self::$instance)) {
			self::$instance = new SG_PortfolioPost_Module;
		}
		return self::$instance;
	}

	public function inited()
	{
		return !is_null(self::$_vars);
	}

	public function initVars($uniq, $params, $defaults, $global, $post_id)
	{
		self::$_vars = self::_initVars(self::moduleName, $uniq, self::$_params, self::$_fields, $params, $defaults, $global, $post_id);
		return TRUE;
	}

	public function setVars($uniq, $post_data, $post_id = NULL)
	{
		$px = self::_getPx($uniq, self::moduleName);

		if (isset($post_data[$px . '_slider']['slides'])) {
			$slides = $post_data[$px . '_slider']['slides'];
			foreach ($slides as $id => $slide) {
				if (!isset($slide['img']) OR empty($slide['img']) OR $slide['img'] == -1) {
					unset($post_data[$px . '_slider']['slides'][$id]);
				}
			}
		} else {
			$post_data[$px . '_slider']['slides'] = array();
		}
		if (empty($post_data[$px . '_slider']['slides'])) {
			$post_data[$px . '_slider']['value'] = self::USE_NONE;
			$post_data[$px . '_slider']['slides'] = array();
			$post_data[$px . '_slider']['last'] = 0;
		} else {
			$post_data[$px . '_slider']['value'] = self::USE_DEFAULT;
		}

		if (isset($post_data[$px . '_type']) AND $post_data[$px . '_type'] == 'img') {
			if ($post_data[$px . '_slider']['value'] == self::USE_DEFAULT) {
				reset($post_data[$px . '_slider']['slides']);
				$fslide = current($post_data[$px . '_slider']['slides']);
				update_post_meta($post_id, '_thumbnail_id', $fslide['img']);
			} else {
				delete_post_meta($post_id, '_thumbnail_id');
			}
		}

		return self::_setVars(self::moduleName, $uniq, self::$_fields, $post_data, $post_id);
	}

	public function resetVars($uniq, $post_id = NULL)
	{
		return self::_resetVars(self::moduleName, $uniq, $post_id);
	}

	public function getMenuItem()
	{
		return __('Content', SG_TDN);
	}

	protected function _getThumbnailField($uid, $params, $value, $default, $ug)
	{
		global $post_ID;
		$nonce = wp_create_nonce('set_post_thumbnail-' . $post_ID);
		$btn_name = __('Get Image', SG_TDN);
		$img = wp_get_attachment_image(get_post_meta($post_ID, '_thumbnail_id', true), 'post-thumbnail');
		$clear = empty($img) ? ' style="display: none;"' : '';

		$c = '<span class="sg-upload-btns">';
		$c .= '<input type="submit" value="' . __('Load Image', SG_TDN) . '" class="button" id="' . $uid . '_load" name="' . $uid . '_load">';
		$c .= '&nbsp;<input type="submit" value="' . __('Clear Image', SG_TDN) . '" class="button sg-photo-clear" id="' . $uid . '_clear" name="' . $uid . '_clear"' . $clear . '><br /><br />';
		$c .= '</span>';
		$c .= '<span id="' . $uid . '_img">' . $img . '</span>';

		$c .= SG_Form::hidden($uid, '');

		$c .= '<script type="text/javascript">';
		$c .= '
//<![CDATA[
jQuery(document).ready(function($){
	if ($("input[name=' . $uid . ']").val() != "") {
		$("#' . $uid . '_clear").show();
	}
	$("#' . $uid . '_clear").click(function() {
		window.SGRemoveThumbnail();
		$("#' . $uid . '_clear").hide();
		return false;
	});
	$("#' . $uid . '_load").click(function() {
		sg_post_nonce = "' . $nonce . '";
		sg_current_uid = "' . $uid . '";
		sg_media_upload_btn_name = "' . $btn_name . '";
		var pID = jQuery("#post_ID").val();
		tb_show("Insert", "media-upload.php?post_id=" + pID + "&custom-media-upload=PI&type=image&TB_iframe=true");
		return false;
	});
});
//]]>
			';
		$c .= '</script>';

		return $c;
	}

	protected function _getSlidesField($uid, $params, $value, $default, $ug)
	{
		global $post_ID;
		$nonce = wp_create_nonce('set_post_thumbnail-' . (empty($post_ID) ? 0 : $post_ID));
		$btn_name = __('Get Image', SG_TDN);
		$ajax_url = get_template_directory_uri() . '/functions/modules/includes/image/ajax.php';

		$slides = (isset($value['slides'])) ? $value['slides'] : array();
		$last = (isset($value['last'])) ? $value['last'] : 0;

		$c = '';

		foreach ($slides as $id => $slide) {
			$c .= '<div class="sg-slide-top">';
				$c .= '<div class="sg-slide">';
					$c .= '<div class="sg-slide-in" id="' . $uid . '-' . $id . '" rel="' . $uid . '[slides][' . $id . ']">';
						$c .= '<a class="button sg-slide-rm ' . $uid . '-rm" href="#">-</a>';
						$c .= '<div class="sg-slide-img ' . $uid . '">';
							$c .= wp_get_attachment_image($slide['img'], 'post-thumbnail');
							$c .= SG_Form::hidden($uid . '[slides][' . $id . '][img]', $slide['img']);
						$c .= '</div>';
					$c .= '</div>';
				$c .= '</div>';
			$c .= '</div>';
		}

		$c .= '<div class="sg-slide-top">';
			$c .= '<div class="sg-slide">';
				$c .= '<div class="sg-slide-in-add">';
					$c .= '<a id="' . $uid . '-add" class="button sg-slide-add" href="#">+</a>';
					$c .= SG_Form::hidden($uid . '[last]', $last, array('id' => $uid . '-last'));
				$c .= '</div>';
			$c .= '</div>';
		$c .= '</div>';

		$c .= '<div class="clear"></div>';

		$c .= '<script type="text/javascript">';
		$c .= '
//<![CDATA[
jQuery(document).ready(function($){
	function ' . $uid . 'sg_get_slide(cur){
		sg_post_nonce = "' . $nonce . '";
		sg_slider_btn_name = "' . $btn_name . '";
		sg_slider_ajaxurl = "' . $ajax_url . '";
		var pID = jQuery("#post_ID").val() || 0;
		window.sg_current_upload_slide = $(cur).parent().attr("id");
		tb_show("Insert", "media-upload.php?post_id=" + pID + "&custom-media-upload=SI&type=image&TB_iframe=true");
	}

	$("#' . $uid . '-add").click(function(e){
		var i = $("#' . $uid . '-last").val();
		$("<div class=\"sg-slide-top\"><div class=\"sg-slide\"><div class=\"sg-slide-in\" id=\"' . $uid . '-" + i + "\" rel=\"' . $uid . '[slides][" + i + "]\"><a href=\"#\" class=\"button sg-slide-rm ' . $uid . '-rm\">-</a><div class=\"sg-slide-img ' . $uid . '\"></div></div></div>").insertBefore($("#' . $uid . '-add").parent().parent().parent());
		$("#' . $uid . '-last").val(++i);
		$(".' . $uid . '-rm").click(function(e){$(this).parent().parent().remove();return false;});
		$(".' . $uid . ':last").click(function(){' . $uid . 'sg_get_slide(this);return false;});
		return false;
	});

	$(".' . $uid . '-rm").click(function(e){
		$(this).parent().parent().parent().remove();
		return false;
	});

	$(".' . $uid . '").click(function(){
		' . $uid . 'sg_get_slide(this);
		return false;
	});
});
//]]>
			';
		$c .= '</script>';

		return $c;
	}

	public function getAdminContent($uniq, $params, $defaults, $global = NULL, $post_id = NULL)
	{
		$fields = self::$_fields;

		$get_posts = new WP_Query;
		$posts = $get_posts->query('post_type=page&meta_key=_wp_page_template&meta_value=pg-portfolio.php&posts_per_page=-1');
		$ppages = array('#' => __('-Last Portfolio Page-', SG_TDN));

		foreach ($posts as $post) {
			$ppages[$post->ID] = trim(esc_html(strip_tags($post->post_title)));
		}

		$fields['parent']['options'] = $ppages;

		return self::_getAdminContent(self::moduleName, $uniq, self::$_params, $fields, self::$_description, $params, $defaults, $global, $post_id);
	}

	public function showSlider($post_id = FALSE)
	{
		if ($post_id === FALSE) return (self::$_vars['slider']['value'] == self::USE_DEFAULT ? (count(self::$_vars['slider']['slides']) > 1) : FALSE);

		$vars = self::_getVars(self::moduleName, 'sg_pos', NULL, $post_id);
		if (!empty($vars) AND isset($vars['slider']['value'])) return ($vars['slider']['value'] == self::USE_DEFAULT ? (count($vars['slider']['slides']) > 1) : FALSE);

		return FALSE;
	}

	public function eSlider($post_id = FALSE, $imgsize = 'sg_post')
	{
		if ($post_id === FALSE) {
			echo '<div class="ef-post-slider' . (self::$_vars['slider_type'] == 'thumbnail' ? '-thumbs' : '') . '">';
				echo '<ul class="slides">';
					foreach (self::$_vars['slider']['slides'] as $id => $slide) {
						echo '<li><div class="proj-img">' . wp_get_attachment_image($slide['img'], $imgsize) . '<a class="lb lb_group" href="' . wp_get_attachment_url($slide['img']) . '"></a></div></li>';
					}
				echo '</ul>';
			echo '</div>';
			if (self::$_vars['slider_type'] == 'thumbnail') {
				echo '<div class="carousel-thumbs">';
					echo '<ul class="slides">';
						foreach (self::$_vars['slider']['slides'] as $slide) {
							echo '<li>' . wp_get_attachment_image($slide['img'], 'post-thumbnail') . '</li>';
						}
					echo '</ul>';
				echo '</div>';
			}
		} else {
			$vars = self::_getVars(self::moduleName, 'sg_pos', NULL, $post_id);
			if (!empty($vars)) {
				foreach ($vars['slider']['slides'] as $id => $slide) {
					echo '<li>' . wp_get_attachment_image($slide['img'], $imgsize) . '</li>';
				}
			}
		}
	}

	function eVideo($post_id = FALSE)
	{
		if ($post_id === FALSE) {
			$video = self::$_vars['video'];
		} else {
			$vars = self::_getVars(self::moduleName, 'sg_pos', NULL, $post_id);
			$video = $vars['video'];
		}

		if (strpos($video, 'youtube.com') OR strpos($video, 'youtu.be')) {
			if (strpos($video, 'youtu.be')) {
				$t = explode('/', $video);
				echo youtubeVideo(array('id' => $t[count($t) - 1]));
			} else {
				$t = parse_url($video);
				parse_str($t['query']);
				echo youtubeVideo(array('id' => $v));
			}
		} else {
			$t = explode('/', $video);
			echo vimeoVideo(array('id' => $t[count($t) - 1]));
		}
	}

	function getVideoUrl($post_id = FALSE)
	{
		if ($post_id === FALSE) {
			$video = self::$_vars['video'];
		} else {
			$vars = self::_getVars(self::moduleName, 'sg_pos', NULL, $post_id);
			$video = $vars['video'];
		}

		if (strpos($video, 'youtu.be')) {
			$t = explode('/', $video);
			return 'http://www.youtube.com/watch?v=' . $t[count($t) - 1];
		}

		return $video;
	}

	function isFeatured($post_id = FALSE)
	{
		if ($post_id === FALSE) {
			return (self::$_vars['featured'] == 'featured');
		} else {
			$vars = self::_getVars(self::moduleName, 'sg_pos', NULL, $post_id);
			return (empty($vars) OR !isset($vars['featured'])) ? FALSE : ($vars['featured'] == 'featured');
		}
	}

	function getType($post_id = FALSE)
	{
		if ($post_id === FALSE) {
			return self::$_vars['type'];
		} else {
			$vars = self::_getVars(self::moduleName, 'sg_pos', NULL, $post_id);
			return (empty($vars) OR !isset($vars['type'])) ? 'img' : $vars['type'];
		}
	}

	public function showLeftBack()
	{
		return (self::$_vars['show_back'] == 'yes' OR self::$_vars['show_back'] == 'left');
	}

	public function showRightBack()
	{
		return (self::$_vars['show_back'] == 'yes' OR self::$_vars['show_back'] == 'right');
	}

	public function showLeftPN()
	{
		return (self::$_vars['show_pn'] == 'yes' OR self::$_vars['show_pn'] == 'left');
	}

	public function showRightPN()
	{
		return (self::$_vars['show_pn'] == 'yes' OR self::$_vars['show_pn'] == 'right');
	}

	public function getParent()
	{
		$id = isset(self::$_vars['parent']) ? self::$_vars['parent'] : '#';

		if ($id == '#') {
			$get_posts = new WP_Query;
			$posts = $get_posts->query('post_type=page&meta_key=_wp_page_template&meta_value=pg-portfolio.php&posts_per_page=1');
			if (isset($posts[0])) $id = $posts[0]->ID;
		}

		return $id;
	}

}